package com.khmer9.boxingapplication.ui.home

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.lifecycle.ViewModelProvider
import androidx.recyclerview.widget.LinearLayoutManager
import com.khmer9.boxingapplication.R
import com.khmer9.boxingapplication.adapter.TopNewsCardAdapter
import com.khmer9.boxingapplication.adapter.CardItem
import com.khmer9.boxingapplication.adapter.NewsFeedCardAdapter
import com.khmer9.boxingapplication.adapter.SubTopNewsCardAdapter
import com.khmer9.boxingapplication.databinding.FragmentHomeBinding

class HomeFragment : Fragment() {

    private var _binding: FragmentHomeBinding? = null
    private lateinit var homeViewModel: HomeViewModel

    // This property is only valid between onCreateView and
    // onDestroyView.
    private val binding get() = _binding!!

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        homeViewModel =
            ViewModelProvider(this).get(HomeViewModel::class.java)

        _binding = FragmentHomeBinding.inflate(inflater, container, false)
        val root: View = binding.root
        setTopNews()
        setSubTopNews()
        setNewsFeed()

        return root
    }

    override fun onDestroyView() {
        super.onDestroyView()
        _binding = null
    }

    private fun setTopNews() {
        val recyclerView = binding.recyclerViewTopNews
        val cardList = createCardList() // Create your card data list here
        val cardAdapter = TopNewsCardAdapter(cardList)

        recyclerView.layoutManager =
            LinearLayoutManager(context, LinearLayoutManager.HORIZONTAL, false)
        recyclerView.adapter = cardAdapter
    }

    private fun setSubTopNews() {
        val recyclerView = binding.recyclerViewSubTopNews
        val cardList = createCardList() // Create your card data list here
        val cardAdapter = SubTopNewsCardAdapter(cardList)

        recyclerView.layoutManager =
            LinearLayoutManager(context, LinearLayoutManager.HORIZONTAL, false)
        recyclerView.adapter = cardAdapter
    }

    private fun setNewsFeed() {
        val recyclerView = binding.recyclerViewNewsFeed
        val cardList = createCardList() // Create your card data list here
        val cardAdapter = NewsFeedCardAdapter(cardList)

        recyclerView.layoutManager =
            LinearLayoutManager(context, LinearLayoutManager.VERTICAL, false)
        recyclerView.adapter = cardAdapter
    }

    private fun createCardList(): List<CardItem> {
        // Create and return your list of CardItems
        return listOf(
            CardItem(R.drawable.ic_launcher_background, "Date 1", "Title 1"),
            CardItem(R.drawable.ic_launcher_background, "Date 2", "Title 2"),
            CardItem(R.drawable.ic_launcher_background, "Date 3", "Title 3"),
            CardItem(R.drawable.ic_launcher_background, "Date 4", "Title 4"),
            CardItem(R.drawable.ic_launcher_background, "Date 5", "Title 5"),
            // Add more card items as needed
        )
    }

}